Coverage for pymend\const.py: 100%

1"""Constant value used across pymend."""

2

3 import re

4

5 DEFAULT_EXCLUDES = re.compile(

6 r"/(\.direnv|\.eggs|\.git|\.hg|\.ipynb_checkpoints|\.mypy_cache|\.nox|\.pytest_cache|\.ruff_cache|\.tox|\.svn|\.venv|\.vscode|__pypackages__|_build|buck-out|build|dist|venv)/" # pylint: disable=line-too-long

7)

8 DEFAULT_DESCRIPTION = "_description_"

9 DEFAULT_TYPE = "_type_"

10 DEFAULT_SUMMARY = "_summary_."

11 DEFAULT_EXCEPTION = "__UnknownError__"